.. -*- coding: utf-8 -*-

What's next?
------------

In this tutorial we have seen you can build a web application in a few minutes simply by defining a data model.
You get a working application which you can then customize without breaking your workflow.
You can show results to customers right from the beginning to make the right decisions early in the process.
This is important in agile development practices.

The next steps will be to discover hooks, security, data sources, digging deeper
into view writing and interface customisation... Still a lot of fun stuff to
discover! You will find more tutorials and howtos in the blog published on the
CubicWeb.org website.
